@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::Compile;
 {
-  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.006'; # TRIAL
+  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.007'; # TRIAL
 }
 # ABSTRACT: common tests to check syntax of your modules
 
@@ -50,7 +50,22 @@ has _test_more_version => (
     default => sub { shift->bail_out_on_fail ? '0.94' : '0.88' },
 );
 
-# -- public methods
+# note that these two attributes could conceivably be settable via dist.ini,
+# to avoid us using filefinders at all.
+has _module_filenames  => (
+    isa => 'ArrayRef[Str]',
+    traits => ['Array'],
+    handles => { _module_filenames => 'elements' },
+    lazy => 1,
+    default => sub { [ map { $_->name } @{shift->found_module_files} ] },
+);
+has _script_filenames => (
+    isa => 'ArrayRef[Str]',
+    traits => ['Array'],
+    handles => { _script_filenames => 'elements' },
+    lazy => 1,
+    default => sub { [ map { $_->name } @{shift->found_script_files} ] },
+);
 
 sub register_prereqs
 {
@@ -62,6 +77,7 @@ sub register_prereqs
         },
         'Test::More' => $self->_test_more_version,
         $self->fake_home ? ( 'File::Temp' => '0' ) : (),
+        $self->_script_filenames ? ( 'Test::Script' => '1.05' ) : (),
     );
 }
 
@@ -110,8 +126,8 @@ CODE
     my $test_more_version = $self->_test_more_version;
     my $plugin_version = $self->VERSION;
 
-    my $module_files = join("\n", map { $_->name } @{$self->found_module_files} );
-    my $script_files = join("\n", map { $_->name } @{$self->found_script_files} );
+    my $module_files = join("\n", $self->_module_filenames);
+    my $script_files = join("\n", $self->_script_filenames);
 
     require Dist::Zilla::File::InMemory;
 
@@ -154,7 +170,7 @@ Dist::Zilla::Plugin::Test::Compile - common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.006
+version 2.007
 
 =head1 SYNOPSIS
 
@@ -373,14 +389,12 @@ COMPILETESTS_SCRIPT_FILES
     COMPILETESTS_FAIL_ON_WARNING
 
 if (@scripts) {
-    SKIP: {
-        eval "use Test::Script 1.05; 1;";
-        skip "Test::Script needed to test script compilation", scalar(@scripts) if $@;
-        foreach my $file ( @scripts ) {
-            my $script = $file;
-            $script =~ s!.*/!!;
-            script_compiles( $file, "$script script compiles" );
-        }
+    require Test::Script;
+    Test::Script->VERSION('1.05');
+    foreach my $file ( @scripts ) {
+        my $script = $file;
+        $script =~ s!.*/!!;
+        Test::Script::script_compiles( $file, "$script script compiles" );
     }
 }
 
